from distutils.core import setup

setup(
    name='wino',
    version='0.0.1',
    author='Scott M. Cruwys',
    author_email='scruwys@gmail.com',
    packages=['wino', 'wino.tests'],
    url='http://pypi.python.org/pypi/wino/',
    license='LICENSE.txt',
    description='Wine.com API wrapper',
)